#
# spec file for package bindfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bindfs
Version:        1.17.7
Release:        1.1
Summary:        Filesystem for mapping directories with alternate permissions
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://bindfs.org/
#Git-Clone:	https://github.com/mpartel/bindfs
Source:         https://bindfs.org/downloads/%name-%version.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse3) >= 3.10.2

%description
bindfs is a FUSE filesystem for mounting a directory to another
location, similarly to mount --bind. The permissions inside the
mountpoint can be altered using various rules.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%files
%doc ChangeLog
%license COPYING
%_bindir/%name
%_mandir/man1/%name.1%{?ext_man}

%changelog
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.17.7
  * Fixed compiler warnings during build
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.17.6:
  * Support negative --{uid,gid}-offset (issue #142)
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.17.4
  * MacOS-specific updates only
* Mon Jun 26 2023 Avindra Goolcharan <avindra@opensuse.org>
- update to 1.17.3:
  * Added MacOS statfs_x implementation
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.17.2:
  * Fixed FD leak when using --block-devices-as-files
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 1.17.1:
  * Fixed --resolve-symlinks when mountpoint name starts
    with source dir name
* Fri Jul 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.17.0
  * Added --map-{passwd,group}-rev
* Fri Feb 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.15.1
  * Support for libfuse3.
  * Fixed non-zero exit code when unable to chdir into source dir.
  * Pass through "-o fsname" to FUSE.
* Fri Oct  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.14.8
  * No user-visible changes (build system only)
* Wed Aug 26 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.14.7
  * Added --map-passwd and --map-group
* Wed Jan  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.14.3
  * No longer check that numeric UIDs and GIDs exist, since
    /etc/passwd etc are not always available.
  * Address -fno-common build [boo#1160257]
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.14.1
  * Do not call realpath() on source dirs starting with "/proc/".
  * Fixes to --gid-offset when used with a setgid bit or with
  - -create-as-mounter.
  * Added --forward-odirect. Bindfs now clears O_DIRECT by default.
  * Resolve symlinks in readdir() so correct attributes are
    returned.
* Wed Feb  7 2018 jengelh@inai.de
- Update to new upstream release 1.13.9
  * Added options --delete-deny and --rename-deny
* Wed Nov  8 2017 aavindraa@gmail.com
- Update to new upstream release 1.13.8
  * Work around `pathconf(..., _PC_NAME_MAX)` erroneously returning
    0 for some source filesystems.
- Use %%make_install macro
* Thu Aug 31 2017 luc14n0@linuxmail.org
- Update to new upstream release 1.13.7
  * Added --block-devices-as-files.
* Tue Sep 27 2016 jengelh@inai.de
- Update to new upstream release 1.13.2
  * Fix bug in readdir() introduced with 1.13.1. This fixes a bug
  when a bindfs mount is exported over NFS.
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 1.13.1
  * Fixed an issue that some users had with reading large directories.
  * Source directory now shown in /etc/mtab.
  * Fixed some test suite compatibility issues with Fedora.
  * Rate limits are now expressed as 64-bit ints.
* Fri Nov 13 2015 jengelh@inai.de
- Update to new upstream release 1.13.0
  * Implemented --resolved-symlink-deletion and added tests.
  * Improved and documented --resolve_symlinks in some edge cases.
  * Better handle symlinks with destructive system calls.
  * Add functionality to transparently resolve symbolic links.
* Tue Sep 22 2015 jengelh@inai.de
- Update to new upstream release 1.12.7
  * OSX fixes only
* Thu Jul 24 2014 tuukka.pasanen@ilmi.fi
- Update to new upstream release 1.12.6
  * Implements throttling
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 1.12.3
  * Implement fuse_utimens instead of fuse_utime
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 1.12.2
  * Added --chmod-filter
* Fri Mar  1 2013 jengelh@inai.de
- Update to new upstream release 1.12
  * Replace "-o user" and "-o group" with "-o force-user" and
  "-o force-group", because the former are standard mount options
  that mount(8) consumes and does not pass on to the helper.
  (bnc#806956)
* Tue Oct 16 2012 jengelh@inai.de
- Update to new upstream release 1.11
  * Be single-threaded by default due to an inherent race condition;
  use -o multithreaded to get the old behavior back.
  * Respect setgid bit on directories when using --create-as-user
* Wed Jul  4 2012 jengelh@inai.de
- Update to new upstream version 1.10.6
  * a memory bug from 1.10.1, and --create-as-user and thread
  safety regressions were resolved
  * honor CFLAGS in ./configure call
  * fix a short-allocation that led to a crash in bindfs_readdir
  * implement a lookup cache to speed up repeated lookups
  (helpful for networked user databases, e.g. on LDAP)
* Sat May  5 2012 jengelh@medozas.de
- Update to new upstream version 1.10.2
  * No changelog was provided
- Remove redundant sections/tags from specfile
- Enable parallel build
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- initial package (1.8.4)
